﻿/*
    Copyright (c) 2011, Jeremy Randall (http://www.auburnrandall.com)
      
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
 
    1. Redistributions of source code must retain the above copyright notice,
    this list of conditions and the following disclaimer.
 
    2. Redistributions in binary form must reproduce the above copyright 
    notice, this list of conditions and the following disclaimer in 
    the documentation and/or other materials provided with the distribution.
 
    3. The names of the authors may not be used to endorse or promote products
    derived from this software without specific prior written permission.
 
    THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED WARRANTIES,
    INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
    FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR
    OR ANY CONTRIBUTORS TO THIS SOFTWARE BE LIABLE FOR ANY DIRECT, INDIRECT,
    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
    LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
    OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
    LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
    NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
    EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Web;
using System.IO;
using System.Net;

namespace FormEngine.Web
{
    /// <summary>
    /// Returns path information for files stored within the AppData folder.
    /// </summary>
    public class WebFileManager : IFileManager
    {
        /// <summary>
        /// Validates that the remote file exists
        /// </summary>
        /// <param name="filename">Filename and path to the remote file.</param>
        /// <returns>True if the file exists</returns>
        public static bool IsLocationValid(string filename)
        {
            bool isvalid = false;

            if (!Uri.IsWellFormedUriString(filename, UriKind.Absolute))
            {
                return isvalid;
            }

            HttpWebRequest request = (HttpWebRequest)WebRequest.Create(filename);
            HttpWebResponse response = null;

            try
            {
                response = (HttpWebResponse)request.GetResponse();
            }
            catch (WebException)
            {
                isvalid = false;
            }

            if (response != null)
            {
                if (response.StatusCode == HttpStatusCode.OK)
                {
                    isvalid = true;
                }
                response.Close();
            }

            return isvalid;
        }

        #region IFileManager Members

        public string GenerateTemporaryFileName(string extension)
        {
            string documentid = Guid.NewGuid().ToString("N");
            string path = ConstructTempPath(string.Format("{0}.{1}", documentid, extension));
            string dir = Path.GetDirectoryName(path);

            if (!Directory.Exists(dir))
            {
                Directory.CreateDirectory(dir);
            }

            return path;
        }

        public string ConstructXmlDataPath(string fileid)
        {
            string path = HttpContext.Current.Server.MapPath(string.Format("~/App_Data/FormEngine/{0}.xml", fileid));
            string dir = Path.GetDirectoryName(path);

            if (!Directory.Exists(dir))
            {
                Directory.CreateDirectory(dir);
            }

            return path;
        }

        #endregion

        /// <summary>
        /// Constructs a path to the temp file locations.
        /// </summary>
        /// <param name="documentname"></param>
        /// <returns></returns>
        private string ConstructTempPath(string documentname)
        {
            string relpath = string.Format("~/App_Data/FormEngine/TempDocuments/{0}", documentname);

            return HttpContext.Current.Server.MapPath(relpath);
        }
    }
}
